<?php

namespace App\Console\Commands\Intuit;

use Illuminate\Console\Command;
use Intuit\Exceptions\NotTokenException;
use Intuit\Jobs\AccountingCustomerUpdate;
use Intuit\Models\Customer as AccAccount;
use Intuit\Traits\ProviderTokenTrait;

use App\Models\Account;

class AccountAdd extends Command
{
	use ProviderTokenTrait;

	/**
	 * The name and signature of the console command.
	 *
	 * @var string
	 */
	protected $signature = 'intuit:account:add'
		.' {id : Account ID}'
		.' {user? : User Email}';

	/**
	 * The console command description.
	 *
	 * @var string
	 */
	protected $description = 'Add an account to quickbooks';

	/**
	 * Execute the console command.
	 *
	 * @return int
	 * @throws NotTokenException
	 */
	public function handle()
	{
		$o = Account::findOrFail($this->argument('id'));

		$acc = new AccAccount;
		$acc->PrimaryEmailAddr = (object)['Address'=>$o->user->email];
		$acc->ResaleNum = $o->sid;
		$acc->GivenName = $o->user->firstname;
		$acc->FamilyName = $o->user->lastname;
		$acc->CompanyName = $o->name;
		$acc->DisplayName = $o->name;
		$acc->FullyQualifiedName = $o->name;
		$acc->Active = (bool)$o->active;

		return AccountingCustomerUpdate::dispatchSync(
			$this->providerToken($this->argument('user')),
			$acc
		);
	}
}